==> quassel_0.6.3.orig.tar.bz2: quassel-0.6.3/src/qtui/qtuisettings.cpp <==
/***************************************************************************
 *   Copyright (C) 2005-09 by the Quassel Project                          *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "qtuisettings.h"

QtUiSettings::QtUiSettings(const QString &subGroup)
  : UiSettings(QString("QtUi/%1").arg(subGroup))
{
}

QtUiSettings::QtUiSettings()
  : UiSettings("QtUi")
{
}

/***********************************************************************/
QtUiStyleSettings::QtUiStyleSettings(const QString &subGroup)
  : UiSettings(QString("QtUiStyle/%1").arg(subGroup))
{
}

QtUiStyleSettings::QtUiStyleSettings()
  : UiSettings("QtUiStyle")
{
}

/***********************************************************************/

WarningsSettings::WarningsSettings() : UiSettings("Warnings") {

}

bool WarningsSettings::showWarning(const QString &key) {
  return localValue(key, true).toBool();
}

void WarningsSettings::setShowWarning(const QString &key, bool show) {
  setLocalValue(key, show);
}

==> quassel-0.9.2.tar.bz2: quassel-0.9.2/src/qtui/qtuisettings.cpp <==
/***************************************************************************
 *   Copyright (C) 2005-2013 by the Quassel Project                        *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#include "qtuisettings.h"

QtUiSettings::QtUiSettings(const QString &subGroup)
    : UiSettings(QString("QtUi/%1").arg(subGroup))
{
}


QtUiSettings::QtUiSettings()
    : UiSettings("QtUi")
{
}


/***********************************************************************/
QtUiStyleSettings::QtUiStyleSettings(const QString &subGroup)
    : UiSettings(QString("QtUiStyle/%1").arg(subGroup))
{
}


QtUiStyleSettings::QtUiStyleSettings()
    : UiSettings("QtUiStyle")
{
}


/***********************************************************************/

WarningsSettings::WarningsSettings() : UiSettings("Warnings")
{
}


bool WarningsSettings::showWarning(const QString &key)
{
    return localValue(key, true).toBool();
}


void WarningsSettings::setShowWarning(const QString &key, bool show)
{
    setLocalValue(key, show);
}
